@@ -103,20 +103,22 @@
 //! ```
 
 #![cfg_attr(test, deny(warnings))]
-#![deny(
-    future_incompatible,
-    missing_copy_implementations,
-    missing_docs,
-    nonstandard_style,
-    rust_2018_idioms,
-    rustdoc,
-    trivial_casts,
-    trivial_numeric_casts,
-    unsafe_code,
-    unused,
-    unused_qualifications
+#![cfg_attr(
+    feature = "fault_injection",
+    deny(
+        future_incompatible,
+        missing_copy_implementations,
+        missing_docs,
+        nonstandard_style,
+        rust_2018_idioms,
+        trivial_casts,
+        trivial_numeric_casts,
+        unsafe_code,
+        unused,
+        unused_qualifications
+    )
 )]
-#![deny(
+#![cfg_attr(feature = "fault_injection", deny(
     // over time, consider enabling the following commented-out lints:
     // clippy::else_if_without_else,
     // clippy::indexing_slicing,
@@ -135,15 +137,15 @@
     clippy::explicit_iter_loop,
     clippy::expl_impl_clone_on_copy,
     clippy::fallible_impl_from,
-    clippy::filter_map,
     clippy::filter_map_next,
-    clippy::manual_find_map,
     clippy::float_arithmetic,
     clippy::get_unwrap,
     clippy::if_not_else,
     clippy::inline_always,
     clippy::invalid_upcast_comparisons,
     clippy::items_after_statements,
+    clippy::manual_filter_map,
+    clippy::manual_find_map,
     clippy::map_flatten,
     clippy::map_unwrap_or,
     clippy::match_same_arms,
@@ -156,7 +158,6 @@
     clippy::non_ascii_literal,
     clippy::path_buf_push_overwrite,
     clippy::print_stdout,
-    clippy::pub_enum_variant_names,
     clippy::shadow_reuse,
     clippy::shadow_same,
     clippy::shadow_unrelated,
@@ -169,8 +170,7 @@
     clippy::unseparated_literal_suffix,
     clippy::wildcard_dependencies,
     clippy::wildcard_enum_match_arm,
-    clippy::wrong_pub_self_convention,
-)]
+))]
 #![allow(
     clippy::match_like_matches_macro,
     clippy::await_holding_lock,
@@ -178,6 +178,9 @@
     clippy::wildcard_enum_match_arm
 )]
 
+/// Async-enabled NATS client.
+pub mod asynk;
+
 mod auth_utils;
 mod client;
 mod connect;
@@ -187,6 +190,7 @@ mod message;
 mod options;
 mod proto;
 mod secure_wipe;
+mod subscription;
 
 #[cfg(feature = "jetstream")]
 /// `JetStream` stream management and consumers.
@@ -209,10 +213,6 @@ fn inject_io_failure() -> io::Result<()> {
     Ok(())
 }
 
-/// Functionality relating to subscribing to a
-/// subject.
-pub mod subscription;
-
 #[doc(hidden)]
 #[deprecated(since = "0.6.0", note = "this has been renamed to `Options`.")]
 pub type ConnectionOptions = Options;
@@ -241,7 +241,7 @@ const DEFAULT_FLUSH_TIMEOUT: Duration = Duration::from_secs(10);
 
 /// Information sent by the server back to this client
 /// during initial connection, and possibly again later.
-#[derive(Debug, Clone)]
+#[derive(Debug, Default, Clone)]
 struct ServerInfo {
     /// The unique identifier of the NATS server.
     pub server_id: String,
@@ -259,7 +259,7 @@ struct ServerInfo {
     /// If this is set, then the server must authenticate using TLS.
     pub tls_required: bool,
     /// Maximum payload size that the server will accept.
-    pub max_payload: i32,
+    pub max_payload: usize,
     /// The protocol version in use.
     pub proto: i8,
     /// The server-assigned client ID. This may change during reconnection.
@@ -287,7 +287,7 @@ impl ServerInfo {
             version: obj["version"].take_string()?,
             auth_required: obj["auth_required"].as_bool().unwrap_or(false),
             tls_required: obj["tls_required"].as_bool().unwrap_or(false),
-            max_payload: obj["max_payload"].as_i32()?,
+            max_payload: obj["max_payload"].as_usize()?,
             proto: obj["proto"].as_i8()?,
             client_id: obj["client_id"].as_u64()?,
             go: obj["go"].take_string()?,
@@ -612,11 +612,7 @@ impl Connection {
     /// # }
     /// ```
     pub fn client_ip(&self) -> io::Result<std::net::IpAddr> {
-        let info = self
-            .0
-            .client
-            .server_info()
-            .expect("INFO should've been received at connection");
+        let info = self.0.client.server_info();
 
         match info.client_ip.as_str() {
             "" => Err(Error::new(
@@ -653,11 +649,7 @@ impl Connection {
     /// # }
     /// ```
     pub fn client_id(&self) -> u64 {
-        self.0
-            .client
-            .server_info()
-            .expect("INFO should've been received at connection")
-            .client_id
+        self.0.client.server_info().client_id
     }
 
     /// Send an unsubscription for all subs then flush the connection, allowing
@@ -728,6 +720,20 @@ impl Connection {
         self.0.client.publish(subject, reply, headers, msg.as_ref())
     }
 
+    /// Returns the maximum payload size the most recently
+    /// connected server will accept.
+    ///
+    /// # Example
+    /// ```
+    /// # fn main() -> std::io::Result<()> {
+    /// let nc = nats::connect("demo.nats.io")?;
+    /// println!("max payload: {:?}", nc.max_payload());
+    /// # Ok(())
+    /// # }
+    pub fn max_payload(&self) -> usize {
+        self.0.client.server_info.lock().max_payload
+    }
+
     fn do_subscribe(
         &self,
         subject: &str,
